=== modified file 'bzrlib/atomicfile.py'
--- bzrlib/atomicfile.py	2006-08-09 15:14:47 +0000
+++ bzrlib/atomicfile.py	2006-08-09 15:57:23 +0000
@@ -21,7 +21,7 @@
 import stat
 import socket
 import sys
-from warnings import warn
+import warnings
 
 from bzrlib import (
     errors,
@@ -78,7 +78,7 @@
     def _get_closed(self):
         symbol_versioning.warn('AtomicFile.closed deprecated in bzr 0.10',
                                DeprecationWarning, stacklevel=2)
-        return self.f is None
+        return self._fd is None
 
     closed = property(_get_closed)
 
@@ -116,4 +116,4 @@
 
     def __del__(self):
         if self._fd is not None:
-            warn("%r leaked" % self)
+            warnings.warn("%r leaked" % self)

=== modified file 'bzrlib/tests/test_atomicfile.py'
--- bzrlib/tests/test_atomicfile.py	2006-08-09 15:14:47 +0000
+++ bzrlib/tests/test_atomicfile.py	2006-08-09 15:57:23 +0000
@@ -24,6 +24,7 @@
     atomicfile,
     errors,
     osutils,
+    symbol_versioning,
     )
 from bzrlib.tests import TestCaseInTempDir
 
@@ -126,3 +127,30 @@
         f.commit()
         st = os.lstat('test')
         self.assertEqualMode(0666 & ~umask, stat.S_IMODE(st.st_mode))
+
+    def test_closed(self):
+        local_warnings = []
+        def capture_warnings(msg, cls, stacklevel=None):
+            self.assertEqual(cls, DeprecationWarning)
+            local_warnings.append(msg)
+
+        method = symbol_versioning.warn
+        try:
+            symbol_versioning.set_warning_method(capture_warnings)
+            f = atomicfile.AtomicFile('test', mode='wb')
+            self.assertEqual(False, f.closed)
+            f.abort()
+            self.assertEqual(True, f.closed)
+
+            f = atomicfile.AtomicFile('test', mode='wb')
+            f.close()
+            self.assertEqual(True, f.closed)
+
+            f = atomicfile.AtomicFile('test', mode='wb')
+            f.commit()
+            self.assertEqual(True, f.closed)
+        finally:
+            symbol_versioning.set_warning_method(method)
+
+        txt = 'AtomicFile.closed deprecated in bzr 0.10'
+        self.assertEqual([txt]*4, local_warnings)

